package SpringMass "Package containing example used for the spring mass calibration"
  model SpringMassModel "Model of a cellphone attached vertically to a spring."
    extends Modelica.Icons.Example;
    inner Modelica.Mechanics.MultiBody.World world annotation(Placement(visible = true, transformation(origin = {10, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.MultiBody.Parts.Fixed fixedPoint(r = {0, 0.2807, 0}) annotation(Placement(visible = true, transformation(origin = {-40, 50}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Mechanics.MultiBody.Forces.Spring spring(c = c, s_unstretched = unstretched_spring_length) annotation(Placement(visible = true, transformation(origin = {-40, 10}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Mechanics.MultiBody.Parts.BodyBox cellPhone(length = 0.150, width = 0.072, height = 0.008, r = {0, 0.15, 0}, lengthDirection = {0, 1, 0}, widthDirection = {1, 0, 0}, r_shape = {0, 0, 0}, density = 1840, r_0.start = {0, -0.03, 0}, color = {0, 0, 200}) annotation(Placement(visible = true, transformation(origin = {-40, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    Modelica.Mechanics.MultiBody.Sensors.AbsoluteSensor acceleration(animation = false, resolveInFrame = Modelica.Mechanics.MultiBody.Types.ResolveInFrameA.world, get_a = true) annotation(Placement(visible = true, transformation(origin = {-10, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput acc annotation(Placement(visible = true, transformation(origin = {-12.04, -40}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.MultiBody.Forces.Damper damper(d = d) annotation(Placement(visible = true, transformation(origin = {-60, 10}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    parameter Modelica.Units.SI.Length unstretched_spring_length = 0.09 "Unstretched spring length";
    parameter Modelica.Units.SI.TranslationalSpringConstant c(min = 0) = 38.27 "Spring constant";
    parameter Modelica.Units.SI.TranslationalDampingConstant d(min = 0, start = 0) = 0.01 "Damping constant";
  equation
    connect(fixedPoint.frame_b, spring.frame_a) annotation(Line(visible = true, origin = {-40, 30}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(spring.frame_b, cellPhone.frame_b) annotation(Line(visible = true, origin = {-40, -10}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(acceleration.frame_a, cellPhone.frame_b) annotation(Line(visible = true, origin = {-29, 10}, points = {{9, -20}, {-11, -20}, {-11, -30}}, color = {95, 95, 95}));
    connect(acceleration.a[2], acc) annotation(Line(visible = true, origin = {-12.013, -33.667}, points = {{0.013, 12.667}, {0.013, -6.333}, {-0.027, -6.333}}, color = {1, 37, 163}));
    connect(damper.frame_a, fixedPoint.frame_b) annotation(Line(visible = true, origin = {-50, 27.916}, points = {{-10, -7.916}, {-10, 2.084}, {10, 2.084}, {10, 12.084}}, color = {95, 95, 95}));
    connect(cellPhone.frame_b, damper.frame_b) annotation(Line(visible = true, origin = {-50, -12.5}, points = {{10, -7.5}, {10, -2.5}, {-10, -2.5}, {-10, 12.5}}, color = {95, 95, 95}));
    annotation(__Wolfram(ControlPanels(Panel(identifier = "brave-cauchy", title = "Model parameters", elements = {Slider(variable = c, label = "Spring constant", min = 0, max = 100), Slider(variable = d, label = "Damping constant", min = 0, max = 1)}))), preferredView = "info", experiment(StopTime = 4), Documentation(figures = {Figure(title = "Acceleration in y-direction", identifier = "139eb", preferred = true, plots = {Plot(curves = {Curve(y = cellPhone.a_0[2], legend = "Acceleration in y-direction")})}), Figure(title = "Velocity in y-direction", identifier = "2243a", plots = {Plot(curves = {Curve(y = cellPhone.v_0[2], legend = "Velocity in y-direction")})}), Figure(title = "Displacement in y-direction", identifier = "a41ff", plots = {Plot(curves = {Curve(y = cellPhone.r_0[2], legend = "Displacement in y-direction")})})}, info = "<html><p>Understand the dynamics of a spring-mass system. This example uses a cellphone, attached vertically to a spring, to record accelerations. The experimental data is then used to calibrate the model parameters.</p>

<p>In order to get the full experience of this example, you need a desktop Wolfram Language product. A free trial download is available at <a href=\"http://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></p>
<p>For the full example, open the accompanying notebook <a href=\"modelica://SpringMass/SpringMass.nb\">SpringMass.nb</a>.</p>
</html>"), Diagram(coordinateSystem(extent = {{-80, -51.673}, {43.214, 72.089}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end SpringMassModel;
  annotation(uses(Modelica(version = "4.0.0")), Documentation(info = "<p>In order to get the full experience of this example, you need a desktop Wolfram Language product. A free trial download is available at <a href=\"http://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></p>
<p>For the full example, open the accompanying notebook <a href=\"modelica://SpringMass/SpringMass.nb\">SpringMass.nb</a>.</p>"), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90.0, -90.0}, {90.0, 90.0}}, radius = 25), Text(visible = true, origin = {12.0, 20.8333}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-102.0, -70.8333}, {78.0, 29.1667}}, textString = "Ex", fontName = "Arial")}));
end SpringMass;
